"""
Provides properties with information about ``behave_restful``.
"""

project = 'behave-restful'
description = 'Implements Gherking language for REST services.'
long_description = '''
Behave Restful implements a language based on Gherkin that allows to test
REST services using the behave python tool.
'''
copyright = '2017 Behave Restful'
author = 'Isaac Rodriguez'
author_email = 'isaac_rodriguez@live.com'
maintainer = 'Isaac Rodriguez'

version = '0.1'
release = '0.1.4'

classifiers = [
    'Development Status :: 1 - Planning',
    'Environment :: Console',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python',
]

keywords = 'behave gherking rest test bdd'